Welcome to PyMarket's documentation!
======================================

PyMarket is a python library designed to ease the simulation and
comparison of different market mechanisms.

Marketplaces can be proposed to solve a diverse array of problems. They
are used to sell ads online, bandwith spectrum, energy, etc.
PyMarket provides a simple environment to try, simulate and compare different
market mechanisms, a task that is inherent to the process of establishing a new
market.

As an example, Local Energy Markets (LEMs) have been proposed to syncronize energy consumption
with surplus of renewable generation. Several mechanisms have been proposed for such a market:
from double sided auctions to p2p trading. 

This library aims to provide a simple interface for such process, making results reproducible.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   installation
   quickstart
   examples
   source/modules
   contributing
   authors
   references

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
